summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:09:37 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:09:37 -0600
commit56e137ce23e6a60bbf92b9bf6e66e94a97aa362b (patch)
tree9f3a3221f523825ffb62ca19a9fc3912379b19ac
parenta327682a10bf292b58ea4f2b5d47509f3150a5c6 (diff)
downloadkdirstat-56e137ce.tar.gz
kdirstat-56e137ce.zip
Rename old tq methods that no longer need a unique name
-rw-r--r--kdirstat/kdirstatapp.cpp2
-rw-r--r--kdirstat/kdirstatsettings.cpp28
-rw-r--r--kdirstat/kdirstatsettings.h2
-rw-r--r--kdirstat/kdirtree.h2
-rw-r--r--kdirstat/kdirtreeview.cpp16
-rw-r--r--kdirstat/kdirtreeview.h4
-rw-r--r--kdirstat/kfeedback.cpp6
-rw-r--r--kdirstat/kpacman.cpp4
-rw-r--r--kdirstat/kpacman.h2
-rw-r--r--kdirstat/ktreemaptile.cpp6
-rw-r--r--kdirstat/ktreemapview.h2
11 files changed, 37 insertions, 37 deletions
diff --git a/kdirstat/kdirstatapp.cpp b/kdirstat/kdirstatapp.cpp
index 5a91375..91579fc 100644
--- a/kdirstat/kdirstatapp.cpp
+++ b/kdirstat/kdirstatapp.cpp
@@ -348,7 +348,7 @@ void KDirStatApp::readMainWinConfig()
KConfig * config = kapp->config();
config->setGroup( "General Options" );
- // tqStatus settings of the various bars and views
+ // Status settings of the various bars and views
_showToolBar->setChecked( config->readBoolEntry( "Show Toolbar", true ) );
toggleToolBar();
diff --git a/kdirstat/kdirstatsettings.h b/kdirstat/kdirstatsettings.h
index f0a5c9e..e860da5 100644
--- a/kdirstat/kdirstatsettings.h
+++ b/kdirstat/kdirstatsettings.h
@@ -426,7 +426,7 @@ namespace KDirStat
* without scrolling. In fact, we never want to see a scroll bar with
* this kind of list box.
**/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Insert an entry for a cleanup action into the list box. Uses the
diff --git a/kdirstat/kdirtree.h b/kdirstat/kdirtree.h
index b00767e..6962c23 100644
--- a/kdirstat/kdirtree.h
+++ b/kdirstat/kdirtree.h
@@ -51,7 +51,7 @@ namespace KDirStat
/**
- * tqStatus of a directory read job.
+ * Status of a directory read job.
**/
typedef enum
{
diff --git a/kdirstat/kdirtreeview.cpp b/kdirstat/kdirtreeview.cpp
index a8f74df..36d368b 100644
--- a/kdirstat/kdirtreeview.cpp
+++ b/kdirstat/kdirtreeview.cpp
@@ -719,14 +719,14 @@ KDirTreeView::setTreeBackground( const TQColor &color )
void
KDirTreeView::ensureContrast()
{
- if ( tqcolorGroup().base() == white ||
- tqcolorGroup().base() == black )
+ if ( colorGroup().base() == white ||
+ colorGroup().base() == black )
{
- setTreeBackground( tqcolorGroup().midlight() );
+ setTreeBackground( colorGroup().midlight() );
}
else
{
- setTreeBackground( tqcolorGroup().base() );
+ setTreeBackground( colorGroup().base() );
}
}
@@ -1593,7 +1593,7 @@ KDirTreeViewItem::compare( TQListViewItem * otherListViewItem,
void
KDirTreeViewItem::paintCell( TQPainter * painter,
- const TQColorGroup & tqcolorGroup,
+ const TQColorGroup & colorGroup,
int column,
int width,
int tqalignment )
@@ -1602,7 +1602,7 @@ KDirTreeViewItem::paintCell( TQPainter * painter,
if ( column == _view->percentBarCol() )
{
- painter->setBackgroundColor( tqcolorGroup.base() );
+ painter->setBackgroundColor( colorGroup.base() );
if ( _percent > 0.0 )
{
@@ -1634,7 +1634,7 @@ KDirTreeViewItem::paintCell( TQPainter * painter,
&& ! _pacMan )
{
TQListViewItem::paintCell( painter,
- tqcolorGroup,
+ colorGroup,
column,
width,
tqalignment );
@@ -1654,7 +1654,7 @@ KDirTreeViewItem::paintCell( TQPainter * painter,
* alignments etc.
*/
TQListViewItem::paintCell( painter,
- tqcolorGroup,
+ colorGroup,
column,
width,
tqalignment );
diff --git a/kdirstat/kdirtreeview.h b/kdirstat/kdirtreeview.h
index 8c9fe8d..9deaac3 100644
--- a/kdirstat/kdirtreeview.h
+++ b/kdirstat/kdirtreeview.h
@@ -352,7 +352,7 @@ namespace KDirStat
* Returns the minimum recommended size for this widget.
* Reimplemented from TQWidget.
**/
- virtual TQSize tqminimumSizeHint() const { return TQSize( 0, 0 ); }
+ virtual TQSize minimumSizeHint() const { return TQSize( 0, 0 ); }
protected slots:
@@ -745,7 +745,7 @@ namespace KDirStat
* Reimplemented from @ref TQListViewItem.
**/
virtual void paintCell ( TQPainter * painter,
- const TQColorGroup & tqcolorGroup,
+ const TQColorGroup & colorGroup,
int column,
int width,
int tqalignment );
diff --git a/kdirstat/kfeedback.cpp b/kdirstat/kfeedback.cpp
index 21e54ff..bcc7005 100644
--- a/kdirstat/kfeedback.cpp
+++ b/kdirstat/kfeedback.cpp
@@ -112,16 +112,16 @@ KFeedbackForm::KFeedbackForm( const TQString & feedbackMailAddress,
label = new TQLabel( i18n( "Questions marked with " ), hbox );
CHECK_PTR( label );
- label->tqsetSizePolicy( pol );
+ label->setSizePolicy( pol );
label = new TQLabel( hbox );
CHECK_PTR( label );
label->setPixmap( KGlobal::iconLoader()->loadIcon( "edit", KIcon::Small ) );
- label->tqsetSizePolicy( pol );
+ label->setSizePolicy( pol );
label = new TQLabel( i18n( " must be answered before a mail can be sent.") , hbox );
CHECK_PTR( label );
- label->tqsetSizePolicy( pol );
+ label->setSizePolicy( pol );
new TQWidget( hbox ); // Fill any leftover space to the right.
diff --git a/kdirstat/kpacman.cpp b/kdirstat/kpacman.cpp
index 22c5176..360d03e 100644
--- a/kdirstat/kpacman.cpp
+++ b/kdirstat/kpacman.cpp
@@ -163,7 +163,7 @@ KPacManAnimation::animate( TQPainter * painter,
// Transfer pixmap into widget
#if 0
- TQPoint offset = painter->tqworldMatrix().map( _pacManRect.topLeft() );
+ TQPoint offset = painter->worldMatrix().map( _pacManRect.topLeft() );
// kdDebug() << "bitBlt() to " << offset.x() << ", " << offset.y() << endl;
bitBlt( _widget, offset, &pixmap );
#endif
@@ -300,7 +300,7 @@ KPacMan::mouseReleaseEvent ( TQMouseEvent *ev )
TQSize
-KPacMan::tqsizeHint() const
+KPacMan::sizeHint() const
{
return TQSize( 16 * _pacManSize, // width - admittedly somewhat random
_pacManSize + 2 * _margin ); // height
diff --git a/kdirstat/kpacman.h b/kdirstat/kpacman.h
index e088cd5..7de9357 100644
--- a/kdirstat/kpacman.h
+++ b/kdirstat/kpacman.h
@@ -211,7 +211,7 @@ public:
*
* Reimplemented from @ref TQWidget.
**/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
public slots:
diff --git a/kdirstat/ktreemaptile.cpp b/kdirstat/ktreemaptile.cpp
index 5826eb0..a65e4dc 100644
--- a/kdirstat/ktreemaptile.cpp
+++ b/kdirstat/ktreemaptile.cpp
@@ -184,12 +184,12 @@ KTreemapTile::createSquarifiedChildren( const TQRect & rect )
#endif
KFileInfoSortedBySizeIterator it( _orig, minSize, KDotEntryAsSubDir );
- TQRect tqchildrenRect = rect;
+ TQRect childrenRect = rect;
while ( *it )
{
- KFileInfoList row = squarify( tqchildrenRect, scale, it );
- tqchildrenRect = layoutRow( tqchildrenRect, scale, row );
+ KFileInfoList row = squarify( childrenRect, scale, it );
+ childrenRect = layoutRow( childrenRect, scale, row );
}
}
diff --git a/kdirstat/ktreemapview.h b/kdirstat/ktreemapview.h
index 29b43c9..119a5b8 100644
--- a/kdirstat/ktreemapview.h
+++ b/kdirstat/ktreemapview.h
@@ -69,7 +69,7 @@ namespace KDirStat
* Returns the minimum recommended size for this widget.
* Reimplemented from TQWidget.
**/
- virtual TQSize tqminimumSizeHint() const { return TQSize( 0, 0 ); }
+ virtual TQSize minimumSizeHint() const { return TQSize( 0, 0 ); }
/**
* Returns this treemap view's currently selected treemap tile or 0 if
diff --git a/kdirstat/kdirstatsettings.cpp b/kdirstat/kdirstatsettings.cpp
index e33a515..7341cf7 100644
--- a/kdirstat/kdirstatsettings.cpp
+++ b/kdirstat/kdirstatsettings.cpp
@@ -79,7 +79,7 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
_generalSettingsPageIndex = pageIndex( page );
new KGeneralSettingsPage( this, page, _mainWin );
- // resize( tqsizeHint() );
+ // resize( sizeHint() );
}
@@ -370,7 +370,7 @@ KCleanupPage::setup()
// (Re-) Initialize list box.
- // _listBox->resize( _listBox->tqsizeHint() );
+ // _listBox->resize( _listBox->sizeHint() );
_listBox->setSelected( 0, true );
}
@@ -437,13 +437,13 @@ KCleanupListBox::KCleanupListBox( TQWidget *parent )
TQSize
-KCleanupListBox::tqsizeHint() const
+KCleanupListBox::sizeHint() const
{
// FIXME: Is this still needed with TQt 2.x?
if ( count() < 1 )
{
// As long as the list is empty, tqsizeHint() would default to
// (0,0) which is ALWAYS just a pain in the ass. We'd rather
// have an absolutely random value than this.
return TQSize( 100, 100 );
@@ -646,7 +646,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
outerBox->activate();
- setMinimumSize( tqsizeHint() );
+ setMinimumSize( sizeHint() );
}
@@ -815,7 +815,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
TQVGroupBox * gbox = new TQVGroupBox( i18n( "Cushion Parameters" ), vbox );
_cushionParams = gbox;
gbox->addSpace( 7 );
- gbox->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+ gbox->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
TQLabel * label = new TQLabel( i18n( "Ambient &Light" ), gbox );
TQHBox * hbox = new TQHBox( gbox );
@@ -823,7 +823,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
DefaultAmbientLight,Qt::Horizontal, hbox );
_ambientLightSB = new TQSpinBox( MinAmbientLight, MaxAmbientLight, 1, // min, max, step
hbox );
- _ambientLightSB->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ _ambientLightSB->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
label->setBuddy( _ambientLightSB );
gbox->addSpace( 7 );
@@ -833,7 +833,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
DefaultHeightScalePercent,Qt::Horizontal, hbox );
_heightScalePercentSB = new TQSpinBox( MinHeightScalePercent, MaxHeightScalePercent, 1, // min, max, step
hbox );
- _heightScalePercentSB->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ _heightScalePercentSB->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
label->setBuddy( _heightScalePercentSB );
gbox->addSpace( 10 );
@@ -847,7 +847,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
_cushionGridColorL = new TQLabel( " " + i18n( "Gr&id Color: " ), hbox );
_cushionGridColor = new KColorButton( hbox );
_cushionGridColorL->setBuddy( _cushionGridColor );
- _cushionGridColorL->tqsetAlignment( AlignRight | AlignVCenter );
+ _cushionGridColorL->setAlignment( AlignRight | AlignVCenter );
// addVStretch( vbox );
@@ -860,17 +860,17 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
label = new TQLabel( i18n( "&Files: " ), _plainTileParams );
_fileFillColor = new KColorButton( _plainTileParams );
label->setBuddy( _fileFillColor );
- label->tqsetAlignment( AlignRight | AlignVCenter );
+ label->setAlignment( AlignRight | AlignVCenter );
label = new TQLabel( " " + i18n( "&Directories: " ), _plainTileParams );
_dirFillColor = new KColorButton( _plainTileParams );
label->setBuddy( _dirFillColor );
- label->tqsetAlignment( AlignRight | AlignVCenter );
+ label->setAlignment( AlignRight | AlignVCenter );
label = new TQLabel( i18n( "Gr&id: " ), _plainTileParams );
_outlineColor = new KColorButton( _plainTileParams );
label->setBuddy( _outlineColor );
- label->tqsetAlignment( AlignRight | AlignVCenter );
+ label->setAlignment( AlignRight | AlignVCenter );
// Misc
@@ -1035,7 +1035,7 @@ void
addHStretch( TQWidget * parent )
{
TQWidget * stretch = new TQWidget( parent );
- stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
+ stretch->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
TQSizePolicy::Minimum, // vert
1, // hstretch
0 ) ); // vstretch
@@ -1046,7 +1046,7 @@ void
addVStretch( TQWidget * parent )
{
TQWidget * stretch = new TQWidget( parent );
- stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
+ stretch->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
TQSizePolicy::Expanding, // vert
0, // hstretch
1 ) ); // vstretch
@@ -437,13 +437,13 @@ KCleanupListBox::KCleanupListBox( TQWidget *parent )
if ( count() < 1 )
{
- // As long as the list is empty, tqsizeHint() would default to
+ // As long as the list is empty, sizeHint() would default to
// (0,0) which is ALWAYS just a pain in the ass. We'd rather
// have an absolutely random value than this.